/*	MessageGUI.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/

package profil;

import java.awt.*;
import java.awt.event.*;
import java.util.*;


/**
 * <p>
 * A simple GUI to display text.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */

public class MessageGUI extends Dialog implements ActionListener, WindowListener
{
	private static int width 	= 40;
	private Vector lines		= new Vector(5);
	private Button b_ok			= new Button("ok");
	
	/**
	 * Build a warning GUI to display <code>message</code>.
	 * This GUI just has an 'ok' button and can be closed with its top-right
	 * button. It splits the message into lines of up to 40 letters, without
	 * cutting words, and displays these lines as a text.
	 * <p>
	 * @param <code>parent</code> the parent <code>Dialog</code> window of this
	 * <code>MessageGUI</code>.
	 * @param <code>message</code> the text to display in the window.
	 */
	
	public MessageGUI(Dialog parent, String message)
	{
		super(parent);
		this.setTitle(" Warning !!");
		buildGUI(message);
	}
	
	
	/**
	 * Build a warning GUI to display <code>message</code>.
	 * Same as <code>MessageGUI(Dialog parent, String message)</code>,
	 * but with the parent window being a <code>Frame</code>.
	 * <p>
	 * @param <code>parent</code> the parent <code>Frame</code> window of this
	 * <code>MessageGUI</code>.
	 * @param <code>message</code> the text to display in the window.
	 */
	 
	public MessageGUI(Frame parent, String message)
	{
		super(parent);
		this.setTitle(" Warning !!");
		buildGUI(message);
	}
	
	private void buildGUI(String message)
	{
		format(message);
		b_ok.addActionListener(this);
		
		this.setBackground(new Color(192, 192, 192));
		this.addWindowListener(this);
		
		
		this.setLayout(new GridLayout(lines.size()+1, 1));
		
		for(int i=0; i<lines.size(); i++)
		{	this.add(new Label((String)lines.elementAt(i)));	}

		this.add(b_ok);
		
		this.pack();
		this.show();
	}
	
	private void format(String message)
	{
		int pos = 0;
		
		while (pos != -1)
		{
			if (message.length() <= width)
				pos = -1;
			else
				pos = message.lastIndexOf(" ", width);
			
			if (pos == -1)
				lines.addElement(message);
			else
			{
				lines.addElement(message.substring(0, pos));
				message = message.substring(pos+1);
			}
		}
	}
	
	/* WINDOW LISTENER
	 */

	public void windowClosing(WindowEvent e)		{	this.dispose();	}
	public void windowClosed(WindowEvent e) 		{	}
	public void windowOpened(WindowEvent e) 		{	}
	public void windowIconified(WindowEvent e) 		{	}
	public void windowDeiconified(WindowEvent e) 	{	}
	public void windowActivated(WindowEvent e) 		{	}
	public void windowDeactivated(WindowEvent e) 	{	}

	/* ACTION LISTENER
	 */

	public void actionPerformed(ActionEvent e)
	{	if (e.getActionCommand().equals("ok"))	this.dispose();	}
}
