/*	ServerToClientHandler.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/

package profil;

import profil.filter.FilterEngine;
import profil.http.Packet;
import java.net.*;


/**
 * <p>
 * Transmits and filters data going the server to the client.
 * <code>ServerToClientHandler</code>s are created by <code>ClientToServerHandler</code>s.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */

public class ServerToClientHandler extends Thread
{
	private FilterEngine filters;
	private SocketHandler sh;
	
	
	/**
	 * Creates a new <code>ServerToClientHandler</code>. It manages
	 * the connection described by this <code>SocketHandler</code>, and
	 * filters data with this <code>FilterEngine</code>.
	 * <p>
	 * @param <code>sh</code> the connection's <code>SocketHandler</code>.
	 * @param <code>filters</code> the <code>FilterEngine</code> associated with
	 * this connection.
	 */
	public ServerToClientHandler(SocketHandler sh, FilterEngine filters)
	{	this.sh 		= sh;
		this.filters 	= filters;
	}
	
	
	/**
	 * Starts this <code>ServerToClientHandler</code>.
	 */
	public void run()
	{		
		try {	Packet packet = new Packet();
				
				while(true)		//loop until mistake, eg socket closed
				{
					sh.readFromServer(packet);
					filters.filter(packet);
					sh.writeToClient(packet);
				}
			
		} catch (Exception ee)	//ie server has unfriendly closed connection
		{	}
	}	
}