/*	SiteFilterGUI.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/

package profil;

import profil.filter.Filter;
import java.awt.*;
import java.awt.event.*;


/**
 * <p>
 * Open a window to create/edit a <code>SiteFilter</code>. 
 * <code>SiteFilterGUI</code> provides allows to set/modify a <code>SiteFilter</code>'s
 * name, regular expression and list of filters. Tests are run to be sure the User
 * enters proper values.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */
 

public class SiteFilterGUI extends Dialog implements ActionListener, WindowListener
{
	private SiteFilter			site;
	private SiteFilterStore 	store;
	private boolean				new_site;


	//private TextField tf_priority	= new TextField("",2);
	//private Label l_priority		= new Label("FILTER's PRIORITY      :");
	
	
	//GUI elements
	private TextField tf_name		= new TextField("", 15);
	private TextField tf_regex		= new TextField("", 20);
	private Label l_name 			= new Label("FILTER's NAME              :");
	private Label l_regex			= new Label("DOMAIN's IDENTIFIER :");
	private List l_filter			= new List(10);
	private List l_site				= new List(10);
	private Button b_add			= new Button(">>");
	private Button b_del			= new Button("<<");
	private Button b_edit			= new Button("Edit");
	private Button	b_ok			= new Button("ok");
	

	
	
	/**
	 * Displays a <code>SiteFilterGUI</code> to create a new <code>SiteFilter</code>. 
	 * <p>
	 * @param <code>store</code> ProFil's <code>SiteFilterStore</code>.
	 * @param <code>parent</code> ProFil's <code>ProFilGUI</code>.
	 */
	public SiteFilterGUI(SiteFilterStore store, Frame parent)
	{	super(parent, true);
		this.store		= store;
		this.new_site	= true;
		this.site		= new SiteFilter();
		
		buildGUI("Create New SiteFilter");		
	}
	
	
	/**
	 * Displays a <code>SiteFilterGUI</code> to edit an existing <code>SiteFilter</code>. 
	 * <p>
	 * @param <code>store</code> ProFil's <code>SiteFilterStore</code>.
	 * @param <code>site</code> the <code>SiteFilter</code> to edit.
	 * @param <code>parent</code> ProFil's <code>ProFilGUI</code>.
	 */
	public SiteFilterGUI(SiteFilterStore store, SiteFilter site, Frame parent)
	{	super(parent, true);
		this.store		= store;
		this.new_site	= false;
		this.site		= site;

		tf_name.setText(site.getName());
		tf_regex.setText(site.getRegex());
		//tf_priority.setText(""+site.getPriority());
		
		site.fillList(l_site);
		
		buildGUI("Edit SiteFilter");
	}


	private void buildGUI(String title)
	{	
		this.setBackground(new Color(192, 192, 192));
		this.addWindowListener(this);
		this.setTitle(title);
		
		site.listAllFilters(l_filter);
		b_ok.addActionListener(this);
		b_add.addActionListener(this);
		b_del.addActionListener(this);
		b_edit.addActionListener(this);
		
		Panel north = new Panel();
		north.setLayout(new GridLayout(/*3*/ 2, 1));
		
		Panel p1 = new Panel();
		p1.setLayout(new FlowLayout(0,1,1));
		p1.add(l_name);
		p1.add(tf_name);
		north.add(p1);
		
		Panel p2 = new Panel();
		p2.setLayout(new FlowLayout(0,1,1));
		p2.add(l_regex);
		p2.add(tf_regex);
		north.add(p2);
		
		/*Panel p3 = new Panel();
		p3.setLayout(new FlowLayout(0,1,1));
		p3.add(l_priority);
		p3.add(tf_priority);
		north.add(p3);*/
		
		Panel right = new Panel();
		
		Panel r_west = new Panel();
		r_west.setLayout(new GridLayout(3,1, 0, 5));	
		r_west.add(b_add);
		r_west.add(b_del);
		r_west.add(b_edit);
		right.add("West", r_west);
		right.add("Center", l_site);
		
		Panel west = new Panel();
		west.add(l_filter);
		
		this.add("North", north);
		this.add("Center", right);
		this.add("West", west);
		this.add("South", b_ok);
		
		
		
		if(!new_site)
		{	if(site.getName().equals("default"))
			{	l_name.setEnabled(false);
				l_regex.setEnabled(false);
				//l_priority.setEnabled(false);
				tf_name.setEnabled(false);
				tf_regex.setEnabled(false);
				//tf_priority.setEnabled(false);
			}
		}		
		
		this.pack();
		this.show();
		
	}
	
	
	
	/* WINDOW LISTENER
	 *	allow users to stop the program when closing the window
	 */

	public void windowClosing(WindowEvent e)		{	this.dispose();	}
	public void windowClosed(WindowEvent e) 		{	}
	public void windowOpened(WindowEvent e) 		{	}
	public void windowIconified(WindowEvent e) 		{	}
	public void windowDeiconified(WindowEvent e) 	{	}
	public void windowActivated(WindowEvent e) 		{	}
	public void windowDeactivated(WindowEvent e) 	{	}



	/* ACTION LISTENER
	 */

	public void actionPerformed(ActionEvent e)
	{	String message = e.getActionCommand();
		if (message.equals(">>"))	do_add();
		if (message.equals("<<"))	do_del();
		if (message.equals("Edit"))	do_edit();
		if (message.equals("ok"))	do_ok();
	}
		
	private void do_add()
	{
		String item = getSelected(l_filter);
		if (item == null)	return;
		
		//should test if item not already in l_site
		if (isPresent(item, l_site))
		{	new MessageGUI(this, "This Filter is already included in this SiteFilter");
			return;
		}
		
		l_site.add(item);
		l_site.select(l_site.getItemCount()-1);
		Filter newf = site.createFilter(item);
		site.addFilter(newf);
	}
	
	private void do_del()
	{
		String item = getSelected(l_site);
		if (item == null)	return;
		
		site.removeFilter(item);
		l_site.remove(item);
	}
	
	private void do_edit()
	{
		String item = getSelected(l_site);
		if (item == null)	return;
		
		site.edit(item, this);
	}
	
	private void do_ok()
	{	
		String name = tf_name.getText();
		String regex = tf_regex.getText();
		int priority = 10;
		
		if (name.equals("default"))
		{	this.dispose();
			return;
		}
		
		if (name.trim().equals(""))
		{	new MessageGUI(this, "You need to specify a name");
			return;
		}
		
		if (regex.trim().equals(""))
		{	new MessageGUI(this, "You need to specify a perl5 compatible regular expression identifying the urls that should be filtered with this SiteFilter");
			return;
		}
		
		/*try {	priority = Integer.parseInt(tf_priority.getText());	}
		catch (Exception e)
		{	new MessageGUI(this, "Priority must be an integer");
			return;
		}
		
		if (priority<0 || priority>9)
		{	new MessageGUI(this, "Priority must be between 0 and 9, 0 being the highest priority");
			return;
		}*/
		
		try {
				synchronized(site)
				{
					site.setName(name);
					site.setRegex(regex);
					//site.setPriority(priority);
				}
		
				if (new_site)	store.addSiteFilter(site);
				
		} catch (Exception e)
		{	new MessageGUI(this, "Error ! invalid Perl5 regular expression");
			return;
		}
		
		this.dispose();
	}

	
	
	// PRIVATE METHODS
	
	private String getSelected(List l)
	{
		String item = l.getSelectedItem();
		l.deselect(l.getSelectedIndex());
		try {	item.equals(" ");	}
		catch(Exception e) 
		{	new MessageGUI(this, "You must select a Filter first");
			return "";
		}
		
		return item;
	}
	
	private boolean isPresent(String item, List l)
	{
		for (int i=0; i<l.getItemCount(); i++)
		{	if (l.getItem(i).equals(item))
				return true;
		}
		
		return false;
	}
}
