/*	SiteFilterStore.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/

package profil;

import com.oroinc.text.regex.*;
import profil.http.*;
import profil.filter.FilterEngine;
import java.util.Vector;
import java.util.Enumeration;
import java.awt.List;
import java.io.Serializable;


/**
 * <p>
 * Open a window to create/edit a <code>SiteFilter</code>. 
 * <code>SiteFilterGUI</code> provides allows to set/modify a <code>SiteFilter</code>'s
 * name, regular expression and list of filters. Tests are run to be sure the User
 * enters proper values.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */


public class SiteFilterStore implements Serializable
{
	//filters related variable
	private Vector sitefilters;
	private SiteFilter defaut;
	
	
	
	public SiteFilterStore()
	{	sitefilters = new Vector(20);
		defaut = new SiteFilter();
		defaut.setName("default");
		try {	defaut.setRegex(".*");	} catch(Exception e) {}
		//defaut.setPriority(10);
	}
	

	public FilterEngine getFilterEngineFor(Packet packet)
	{	//attention !!!!!!!!!!!!!!!!!!!!!
		//prendre en compte actif/pas actif !!
		HTTPRequest r = packet.getRequest();
		Perl5Matcher matcher = new Perl5Matcher();
		String uri = r.getServer()+r.getURI();
		int i=0;
		SiteFilter site;
		
		while(i<sitefilters.size())
		{	
			site = (SiteFilter)sitefilters.elementAt(i);
			
			if (site.isActiv() && matcher.contains(uri, site.getPattern()))
			{	
				if (i>3)	//move the filter i in first pos in vector, to be found first next time
				{	sitefilters.remove(i);
					sitefilters.insertElementAt(site, 1);
				}

System.out.println("Store> "+site.getName()+" match "+site.getRegex());

				return (FilterEngine)site;
			}
			i++;
		}
System.out.println("Store> match default filter");
		return (FilterEngine)defaut;
	}

	
	public void addSiteFilter(SiteFilter site)	{	sitefilters.add(site);	}
	
	
	public void refreshList(java.awt.List list)
	{	list.removeAll();
		SiteFilter f;
		String line;
		for(Enumeration enum = sitefilters.elements(); enum.hasMoreElements();)
		{	
			f = (SiteFilter)enum.nextElement();
			//line = ""+f.getPriority();
			//if (line.length() == 1)	line += " ";
			line = "";
			if (f.isActiv())		line += "   *   ";
			else					line += "       ";
			line += f.getName();
			
			list.add(line);
		}
	
	}
	
	public SiteFilter getDefault()
	{	return defaut;	}
	
	
	public SiteFilter getSiteFilter(String name)
	{	return (SiteFilter)sitefilters.get(searchSiteFilter(name));	}
	
	
	public void delSiteFilter(String name)
	{	sitefilters.remove(searchSiteFilter(name));	}
	
	
	public void switchSiteFilter(String name)
	{	SiteFilter f = (SiteFilter)sitefilters.get(searchSiteFilter(name));
		f.setActiv(!f.isActiv());
	}


	
	/*********** PRIVATE ************/
	//serach in 'filters' the filter of type 'type', and return its index
	private int searchSiteFilter(String name)
	{	int pos;
		for (	pos=0;
				pos<sitefilters.size() && !((SiteFilter)sitefilters.elementAt(pos)).getName().equals(name);
				pos++	)	{}
				
		return pos;
	}
}
	