/*	CookieFilter.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/

package profil.filter;

import profil.http.*;
import java.awt.Dialog;

/**
 * <p>
 * This <code>Filter</code> blocks every request made by the user-agent to a CGI script.
 * It thus blocks any attempt to pass arguments to a server via POST or GET 
 * (GET URI?arguments), or to request files with the extension *.pl, *.php, *.cgi.
 * It instead sends back a 404 to the user-agent.
 * May be usefull to avoid some automaticaly generated advertisements. 
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */


public class CGIFilter extends Filter
{
	//true => will be stopped
	public boolean stop_POST;
	public boolean stop_PHP;
	public boolean stop_CGI;
	public boolean stop_PERL;
	public boolean stop_GETarg;
	
	
	
	public CGIFilter()
	{	stop_POST 		= true;
		stop_PHP  		= true;
		stop_CGI  		= true;
		stop_PERL 		= true;
		stop_GETarg		= true;
	}
	
	public int getTYPE()			{	return 5;	}
	public Filter duplicate()		{	return new CGIFilter();	}
	
	
	public void edit(Dialog owner)
	{	new CGIFilterGUI(owner, this);	}
	
	
	// This Filter removes the headers 'Cookie' and 'Set-Cookie' from an HTTP header
	public void filter(Packet packet)
	{	
//System.out.println("CGI> filter ("+stop_POST+" "+stop_CGI+")");
		if (packet.fromClient() && packet.headerReceived())
		{
			HTTPRequest request = packet.getRequest();
			String method = request.getMethod();
			String url = request.getURI();

System.out.println("CGI> method:"+method+"  request:"+url);
			//if POST and post forbidden -> stop packet.
			if (stop_POST && method.equals("POST"))
			{	
System.out.println("CGI> POST stopped");
				packet.doNotSend();
				return;	
			}
			
			//other method than get -> return.
			if (!method.equals("GET"))		return;
			
			int pos_qm = url.indexOf("?");
			int pos_p;
			
			if (pos_qm == -1)		pos_p = url.lastIndexOf(".");
			else					pos_p = url.lastIndexOf(".", pos_qm);
			
			// if call contain no extension but arguments with ?, and stop_GETarg set -> stop packet.
			if (stop_GETarg && pos_p==-1 && pos_qm!=-1)
			{	
System.out.println("CGI> stopped GET ?*");				
				packet.doNotSend();
				return;	
			}
				
			// if call does not contain extension -> return.
			if (pos_p == -1)	return;
			
			// if call to php, cgi or perl, and corresponding flag set -> stop packet.
			String ext;
			if (pos_qm == -1)		ext = (url.substring(pos_p)).toLowerCase();
			else					ext = (url.substring(pos_p, pos_qm)).toLowerCase();				
				
//System.out.println("CGI> ext="+ext);
				
			if (    (stop_PHP && (ext.equals(".php") || ext.equals(".php3")) )
				 || (stop_CGI && ext.equals(".cgi"))
				 || (stop_PERL && (ext.equals(".perl") || ext.equals(".pl")) )
			)
			{	
System.out.println("CGI> stopped "+ext);					
				packet.doNotSend();
				return;	
			}

		}
	}
}