/*	CGIFilterGUI.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/


package profil.filter;

import java.awt.*;
import java.awt.event.*;

/**
 * <p>
 * Configuration GUI for CGIFilters.
 * Allows you to choose precisely which type of CGI calls will be filtered:
 * POST calls, GET calls with no extension to script but arguments passed,
 * call to file with extensions php, pl, perl, cgi.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */


public class CGIFilterGUI extends Dialog implements WindowListener, ActionListener
{
	private CGIFilter filter;
	
	private Label l_txt			= new Label("Stop the following requests:");
	private Checkbox cb_post	= new Checkbox("all POST methods");
	private Checkbox cb_php		= new Checkbox("calls to PHP scripts");
	private Checkbox cb_cgi		= new Checkbox("calls to CGI scripts");
	private Checkbox cb_perl	= new Checkbox("calls to PERL scripts");
	private Checkbox cb_getarg	= new Checkbox("pass parameters to undefined script");
	private Button b_ok			= new Button("ok");
	
	/**
	 * Configuration GUI of this <code>CGIFilter</code>.
	 * <p>
	 * @param <code>owner</code> the parent <code>Dialog</code> of this <code>DefaultFilterGUI</code>.
	 * @param <code>message</code> the title and lines of text to display in this <code>DefaultFilterGUI</code>.
	 */
	public CGIFilterGUI(Dialog owner, CGIFilter filter)
	{
		super(owner);
		this.filter = filter;	
		this.setTitle("Edit CGIFilter");	
		this.setBackground(new Color(192, 192, 192));
		this.addWindowListener(this);
		
		this.add("North", l_txt);
		
		cb_post.setState(filter.stop_POST);
		cb_php.setState(filter.stop_PHP);
		cb_cgi.setState(filter.stop_CGI);
		cb_perl.setState(filter.stop_PERL);
		cb_getarg.setState(filter.stop_GETarg);
		
		Panel p = new Panel();
		p.setLayout(new GridLayout(5,1));
		p.add(cb_post);
		p.add(cb_php);
		p.add(cb_cgi);
		p.add(cb_perl);
		p.add(cb_getarg);
		this.add("Center", p);
		
		b_ok.addActionListener(this);
		this.add("South", b_ok);
		
		this.pack();
		this.show();
	}
	
	/* WINDOW LISTENER
	 */

	public void windowClosing(WindowEvent e)		{	this.dispose();	}
	public void windowClosed(WindowEvent e) 		{	}
	public void windowOpened(WindowEvent e) 		{	}
	public void windowIconified(WindowEvent e) 		{	}
	public void windowDeiconified(WindowEvent e) 	{	}
	public void windowActivated(WindowEvent e) 		{	}
	public void windowDeactivated(WindowEvent e) 	{	}

	
	/* ACTION LISTENER
	 */

	public void actionPerformed(ActionEvent e)
	{	
		if ( (e.getActionCommand()).equals("ok") )
		{
			filter.stop_POST 	= cb_post.getState();
			filter.stop_PHP 	= cb_php.getState();
			filter.stop_CGI 	= cb_cgi.getState();
			filter.stop_PERL 	= cb_perl.getState();
			filter.stop_GETarg 	= cb_getarg.getState();
			this.dispose();
		}
	}


}
