/*	DefaultFilterGUI.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/


package profil.filter;

import java.awt.*;
import java.awt.event.*;

/**
 * <p>
 * A default Graphical User Interface with only a 'window close' button, that
 * displays an array of Strings. It typicaly used by <code>Filter</code>s that
 * do not need a configuration interface for their method <code>edit()</code>, and
 * just want to inform the user of their use.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */


public class DefaultFilterGUI extends Dialog implements WindowListener
{
	
	/**
	 * Creates and displays a <code>DefaultFilterGUI</code>. The array of Strings
	 * <code>message</code> contains as a first element the title of the
	 * <code>DefaultFilterGUI</code>'s window, and then the lines to display in
	 * this window.
	 * <p>
	 * @param <code>owner</code> the parent <code>Dialog</code> of this <code>DefaultFilterGUI</code>.
	 * @param <code>message</code> the title and lines of text to display in this <code>DefaultFilterGUI</code>.
	 */
	public DefaultFilterGUI(Dialog owner, String[] message)
	{
		super(owner);
		int l = message.length;
		
		this.setTitle(message[0]);	
		this.setBackground(new Color(192, 192, 192));
		this.addWindowListener(this);
		this.setLayout(new GridLayout(l-1, 1));
		
		for(int i=1; i<l; i++)
		{	this.add(new Label(message[i]));	}
		
		this.pack();
		this.show();
	}
	
	/* WINDOW LISTENER
	 */

	public void windowClosing(WindowEvent e)		{	this.dispose();	}
	public void windowClosed(WindowEvent e) 		{	}
	public void windowOpened(WindowEvent e) 		{	}
	public void windowIconified(WindowEvent e) 		{	}
	public void windowDeiconified(WindowEvent e) 	{	}
	public void windowActivated(WindowEvent e) 		{	}
	public void windowDeactivated(WindowEvent e) 	{	}
}
