/*	HeaderFilter.java		(ProFil)
 *	Set indentation=4
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/

package profil.filter;

import profil.http.*;
import java.awt.Dialog;
import java.util.Vector;

/**
 * <p>
 * <code>HeaderFilter</code> parses requests to remove or change some headers
 * dealing with protection of anonymity. One can remove the headers 'From', 'Referer'
 * and 'Pragma', and remove or edit 'User-Agent'. Especially, the filter can be ask to
 * give User-Agent a sequence of values choosen randomly in a list of authorized values.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */


public class HeaderFilter extends Filter
{
	
	public HeaderFilter()
	{	
		FROM = false;
		REFERER = false;
		PRAGMA = false;
		USER_AGENT = false;
		SWAP_AGENT = false;
		agent_names = new Vector(3);
	}
	
	public int getTYPE()			{	return 4;	}
	public Filter duplicate()		{	return new HeaderFilter();	}
	
	
	public boolean FROM;
	public boolean REFERER;
	public boolean PRAGMA;
	public boolean USER_AGENT;
	public boolean SWAP_AGENT;
	public Vector agent_names;
	
	public void edit(Dialog owner)
	{	new HeaderFilterGUI(owner, this);	}
	
	
	/**
	 * Removes or replaces some headers as specified during configuration.
	 */
	public void filter(Packet packet)
	{	
		if (packet.fromClient() && packet.headerReceived())
		{
			HTTPHeaders headers = packet.getHeaders();
			
			if (FROM)		headers.removeHeader("From");
			if (REFERER)	headers.removeHeader("Referer");
			if (PRAGMA)		headers.removeHeader("From");
			if (USER_AGENT)	headers.removeHeader("User-Agent");
			
			if (SWAP_AGENT)
			{
				if (agent_names.size() == 0)
					headers.removeHeader("User-Agent");
				else
				{
					if (agent_names.size() == 0)
						headers.removeHeader("User-Agent");
					else
					{
						int pos = (int)(Math.floor(agent_names.size()*Math.random()));
						headers.setHeaderValue("user-agent", (String)agent_names.elementAt(pos));
					}
				}
			}
			
		}
	}
}