/*	DefaultFilterGUI.java		(ProFil)
 *	Set indentation=4
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/


package profil.filter;

import java.awt.*;
import java.awt.event.*;
import java.util.Vector;

/**
 * <p>
 * Configuration GUI for HeaderFilters.
 * Allows you to choose among a list of anonymity-related headers
 * which one to allow or disallow, or which value to give them.
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */


public class HeaderFilterGUI extends Dialog implements WindowListener, ActionListener
{
	private HeaderFilter filter;
	private Vector agent_names;
	
	private Label l_txt1		= new Label("Remove the following headers:");
	private Checkbox cb_from	= new Checkbox("From");
	private Checkbox cb_referer	= new Checkbox("Referer");
	private Checkbox cb_pragma	= new Checkbox("Pragma");
	private Label l_txt2		= new Label("Header User-Agent:");
	private CheckboxGroup cbg 	= new CheckboxGroup();
	private Checkbox cb_user	= new Checkbox("Remove", cbg, false);
	private Checkbox cb_swap	= new Checkbox("Choose value randomly among:", cbg, false);
	
	private Checkbox cb_ua_0	= new Checkbox("Navigator 3.0 win95");
	private Checkbox cb_ua_1	= new Checkbox("Communicator 4.7 winNT");
	private Checkbox cb_ua_2	= new Checkbox("MSIE 3.0 win95");
	private Checkbox cb_ua_3	= new Checkbox("MSIE 4.0 win98");
	private Checkbox cb_ua_4	= new Checkbox("MSIE 5.0 win98");
	
	private Button b_ok			= new Button("ok");
	
	private String[] identifiers	=	{	"Mozilla/3.0Gold (Win95; I)",
											"Mozilla/4.7 [en] (WinNT; I)",
											"Mozilla/2.0 (compatible; MSIE 3.0A; Windows 95)",
											"Mozilla/4.0 (compatible; MSIE 4.01; Windows 98)",
											"Mozilla/4.0 (compatible; MSIE 5.0; Windows 98)"
										};
	
	/**
	 * Configuration GUI of this <code>CGIFilter</code>.
	 * <p>
	 * @param <code>owner</code> the parent <code>Dialog</code> of this <code>DefaultFilterGUI</code>.
	 * @param <code>message</code> the title and lines of text to display in this <code>DefaultFilterGUI</code>.
	 */
	public HeaderFilterGUI(Dialog owner, HeaderFilter filter)
	{
		super(owner);
		this.filter = filter;
		this.agent_names = filter.agent_names;
		
		this.setTitle("Edit HeaderFilter");	
		this.setBackground(new Color(192, 192, 192));
		this.addWindowListener(this);
		
		cb_from.setState(filter.FROM);
		cb_referer.setState(filter.REFERER);
		cb_pragma.setState(filter.PRAGMA);
		
		cb_user.setState(filter.USER_AGENT);
		cb_swap.setState(filter.SWAP_AGENT);
		
		cb_ua_0.setState(agent_names.contains(identifiers[0]));
		cb_ua_1.setState(agent_names.contains(identifiers[1]));
		cb_ua_2.setState(agent_names.contains(identifiers[2]));
		cb_ua_3.setState(agent_names.contains(identifiers[3]));
		cb_ua_4.setState(agent_names.contains(identifiers[4]));
		
		Panel p0 = new Panel();
		p0.setLayout(new GridLayout(1,3));
		p0.add(cb_from);
		p0.add(cb_referer);
		p0.add(cb_pragma);
		
		Panel p1 = new Panel();
		p1.setLayout(new GridLayout(5,1));
		p1.add(l_txt1);
		p1.add(p0);
		p1.add(l_txt2);
		p1.add(cb_user);
		p1.add(cb_swap);
		this.add("North", p1);
		
		Panel p3 = new Panel();
		Panel p2 = new Panel();
		p2.setLayout(new GridLayout(3,2));
		p2.add(cb_ua_0);
		p2.add(cb_ua_1);
		p2.add(cb_ua_2);
		p2.add(cb_ua_3);
		p2.add(cb_ua_4);
		p2.add(new Label(""));
		p3.add("Center", p2);
		this.add(p3);
		
		b_ok.addActionListener(this);
		this.add("South", b_ok);
		
		this.pack();
		this.show();
	}
	
	

	
	/* WINDOW LISTENER
	 */

	public void windowClosing(WindowEvent e)		{	this.dispose();	}
	public void windowClosed(WindowEvent e) 		{	}
	public void windowOpened(WindowEvent e) 		{	}
	public void windowIconified(WindowEvent e) 		{	}
	public void windowDeiconified(WindowEvent e) 	{	}
	public void windowActivated(WindowEvent e) 		{	}
	public void windowDeactivated(WindowEvent e) 	{	}

	
	/* ACTION LISTENER
	 */

	public void actionPerformed(ActionEvent e)
	{	
		if ( (e.getActionCommand()).equals("ok") )
		{
			filter.FROM 		= cb_from.getState();
			filter.REFERER 		= cb_referer.getState();
			filter.PRAGMA 		= cb_pragma.getState();
			filter.USER_AGENT 	= cb_user.getState();
			filter.SWAP_AGENT 	= cb_swap.getState();
			
			agent_names = new Vector(3);
			if (cb_ua_0.getState())	agent_names.add(identifiers[0]);
			if (cb_ua_1.getState())	agent_names.add(identifiers[1]);
			if (cb_ua_2.getState())	agent_names.add(identifiers[2]);
			if (cb_ua_3.getState())	agent_names.add(identifiers[3]);
			if (cb_ua_4.getState())	agent_names.add(identifiers[4]);
			filter.agent_names = agent_names;
			
			this.dispose();
		}
	}


}
