/*	PictureFilter.java		(ProFil)
 *
 *	Erwan Lemonnier - september 2000
 *
 *****************************************/
 
 
package profil.filter;

import profil.http.*;
import java.awt.Dialog;


/**
 * <p>
 * This <code>Filter</code> parses the data going from a client to a server, and when
 * a request for a picture is found, it does not transmit it to the server and
 * sends a '404 not found' back to the client.
 * <p>
 * It stops all request for documents ending with the file extension "jpg", "jpeg",
 * "gif" and "bmp".
 * <p>
 * @author 		Erwan Lemonnier <code><a href="mailto:erwan_lemonnier@hotmail.com">[erwan_lemonnier@hotmail.com]</a></code>
 * @version 	<code>1.1 [released 09/2000]</code>
 */


public class PictureFilter extends Filter
{
	public PictureFilter()			{	}
	public int getTYPE()			{	return 1;	}
	public Filter duplicate()		{	return new PictureFilter();	}
	
	
	public void edit(Dialog owner)
	{	String[] msg = {	"PictureFilter",
							"Will not transmit request for",
							"pictures of type :",
							"JPG, JPEG, GIF & BMP"
						};
		new DefaultFilterGUI(owner, msg);
	}
	
	//set the send_allowed to false in packets requesting pictures
	public void filter(Packet packet)
	{	
		if (packet.fromClient() && packet.headerReceived())
		{
			String uri = (packet.getRequest()).getURI();
			if (uri.length() < 5)	return;
			
			uri = (uri.substring(uri.length()-4)).toLowerCase();
			String pict = "jpeg .jpg .gif .bmp";

			if ( pict.indexOf(uri) != -1 )	packet.doNotSend();
		}
	}
		
}